import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const titleText = 'Jouw uitgaven van december 2019';
const xAxisLabelText = 'Tot hier gaat het goed!';
const xAxisLabelTextTwo = 'Tot hier is wat het NIBUD advieseerd';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const xValue = d => d['population'];
  const yValue = d => d.post;
  const type = d => d.soort;
  const margin = { top: 50, right: 40, bottom: 77, left: 180 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  function colorPalette() {
    return d3.scaleOrdinal(d3.schemeSet2);
  }

  const color = colorPalette();

  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);

  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .padding(0.1);

  const g = svg
    .append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);

  //moet line worden
  g.append('rect')
    .attr('class', 'rood')
    .attr('y', 0)
    .attr('x', 0)
    .attr('width', 750)
    .attr('height', 373)
    .style('fill', '#fefebe');

  g.append('rect')
    .attr('class', 'groen')
    .attr('y', 0)
    .attr('x', 0)
    .attr('width', 273)
    .attr('height', 373)
    .style('fill', '#cca9dd');

  const xAxisTickFormat = number => format('.0%')(number);
  //.replace('K', '%');

  const xAxis = axisBottom(xScale)
    .tickFormat(xAxisTickFormat)
    .tickSizeInner(-innerHeight);

  g.append('g')
    .call(axisLeft(yScale))
    .selectAll('.domain, .tick line')
    .remove();

  const xAxisG = g
    .append('g')
    .call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);

  xAxisG.select('.domain').remove();

  xAxisG
    .append('text')
    .attr('class', 'axis-label')
    .attr('y', 35)
    .attr('x', 276)
    .attr('fill', 'black')
    .text(xAxisLabelText);

  xAxisG
    .append('text')
    .attr('class', 'axis-label')
    .attr('y', 50)
    .attr('x', 276)
    .attr('fill', 'black')
    .text(xAxisLabelTextTwo);

  g.selectAll('rect')
    .data(data)
    .enter()
    .append('rect')
    .attr('class', type)
    .attr('y', d => yScale(yValue(d)))
    .attr('width', d => xScale(xValue(d)))
    .attr('height', yScale.bandwidth())
    .style('fill', d => color(type(d)));

  g.append('text')
    .attr('class', 'title')
    .attr('y', -10)
    .text(titleText);
};

csv('data.csv').then(data => {
  console.log(data)
  data.forEach(d => {
    d.population = +d.population;
  });
  render(data);
});
